summaryrefslogtreecommitdiff
path: root/mutt
diff options
context:
space:
mode:
authorBen Sima <ben@bsima.me>2018-07-12 09:07:09 -0700
committerBen Sima <ben@bsima.me>2018-07-12 09:07:09 -0700
commita25f817202787a140cee28bd4e1a385f1119f30c (patch)
tree201635262e6f8dfe54db1449a9176b69014209c8 /mutt
parentd55f9eef8bb90af4606a70f5367273d8ebcdb972 (diff)
Email tweaks
Diffstat (limited to 'mutt')
-rwxr-xr-xmutt/notmuch-hook.sh12
1 files changed, 8 insertions, 4 deletions
diff --git a/mutt/notmuch-hook.sh b/mutt/notmuch-hook.sh
index eec6680..29fe9dc 100755
--- a/mutt/notmuch-hook.sh
+++ b/mutt/notmuch-hook.sh
@@ -5,14 +5,18 @@ notmuch new
# retag all "new" messages "inbox" and "unread"
notmuch tag +inbox +unread -new -- tag:new
-# tag all messages from "me" as sent and rmeove tags inbox and unread
-notmuch tag -new -unread -inbox +sent -- from:ben@bsima.me or from:bsima@me.com
+# tag all messages from "me" as sent
+notmuch tag +sent -- from:ben@bsima.me
+
+# tag TODOs from myself
+notmuch tag +todo -- subject:TODO
# tag some newsletters, but don't show them in inbox
-notmuch tag +newsletters -new -inbox -- \
+notmuch tag +newsletters -inbox -- \
from:the-morning-paper@onelanday.co.uk or \
from:newsletter@fightaging.org or \
- subject:'The Reading List Email*'
+ subject:'The Reading List Email*' or \
+ from:info@haskellweekly.news
# tag logwatch emails & remove from inbox
notmuch tag +logwatch -new -inbox -- subject:'Logwatch*'